@@ -5,12 +5,12 @@ from .utils import parse_token, JWTParseError
 
 class JWTAuthenticationBackend(ModelBackend):
     """Custom django authentication backend using JWT"""
-    def authenticate(self, authorization_token=None, **kwargs):
+    def authenticate(self, authentication_token=None, **kwargs):
         UserModel = get_user_model()
-        if authorization_token is None:
+        if authentication_token is None:
             return
         try:
-            token_data = parse_token(authorization_token)
+            token_data = parse_token(authentication_token)
             return UserModel._default_manager.get(pk=token_data['id'])
         except JWTParseError:
             pass
